@@ -1,13 +1,7 @@
 """Main library."""
-from A import A
-from B import B
-
-__version__ = "0.0.1"
 
 
-class YeHomeRobotLib(
-    A, B
-):
+class YeHomeRobotLib:
     @staticmethod
     def hi(name):
         print(f"hi, {name}")
